PCRGLOBWB_UTILS
======================================

This is the read-the-docs documentation of PCRGLOBWB_UTILS, a Python-package
containing useful functions and scripts to evaluate output from PCR-GLOBWB.

.. note:: It is still very much in the testing phase, so no guarantees that it works on 
   any platform and any data!

.. toctree::
   :numbered:
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   contributing
   authors
   history
   API Docs <api/index>
   license

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
